const path = require('path')
const optionFun = require('./utils') // 因为文件会被webpack读取，只能引入由module.export={}导出的数据

const optionInfo = {
  raw: true,
  preventExtract: true, // 这个加载器将自动从html令牌内容中提取脚本和样式标签
  // 定义处理规则
  preprocess: optionFun.optionPreprocess, // option处理规则函数
  use: [
    [
      require('markdown-it-container'),
      'demo',
      {
        validate: optionFun.optionValidate, // option的validate函数
        render: optionFun.optionRender // option的render函数
      }
    ],
    [require('markdown-it-container'), 'tip'],
    [require('markdown-it-container'), 'warning']
  ]
}

module.exports = {
  // 修改 pages 入口
  pages: {
    index: {
      entry: 'examples/main.js', // 入口
      template: 'public/index.html', // 模板
      filename: 'index.html' // 输出文件
    }
  },
  parallel: false,
  // 扩展 webpack 配置
  chainWebpack: config => {
    // @ 默认指向 src 目录，这里要改成 examples
    // 另外也可以新增一个 ~ 指向 packages
    config.resolve.alias
      .set('@', path.resolve('examples'))
      .set('~', path.resolve('packages'))

    // 把 packages 和 examples 加入编译，因为新增的文件默认是不被 webpack 处理的
    config.module
      .rule('js')
      .include.add(/packages/)
      .end()
      .include.add(/examples/)
      .end()
      .use('babel')
      .loader('babel-loader')
      .tap(options => {
        // 修改它的选项...
        return options
      })
    config.module
      .rule('md')
      .test(/\.md/)
      .use('vue-loader')
      .loader('vue-loader')
      .end()
      .use('vue-markdown-loader')
      .loader('vue-markdown-loader/lib/markdown-compiler')
      .options(optionInfo)
  }
}
